@@ -1809,7 +1809,8 @@ class FacturaATR(Factura):
     def te_lectures_amb_decimals(self):
         if self.datos_factura.tarifa_atr_fact not in TARIFES_TD:
             return False
-
+        if self.datos_factura.tipo_factura in ('G', 'C'):
+            return False
         for c in self.get_comptadors():
             for l in c.get_lectures(force_no_transforma_no_td_a_td=True):
                 if isinstance(l.consumo_calculado, int):
@@ -2457,10 +2458,10 @@ class FacturaATR(Factura):
 
     def get_maximetres_consumidor(self):
         data = []
-        if hasattr(self, 'informacion_al_consumidor'):
+        if hasattr(self, 'informacion_al_consumidor') and bool(self.informacion_al_consumidor):
             informacion_al_consumidor = self.informacion_al_consumidor
             fecha_hasta = self.datos_factura.fecha_hasta_factura
-            if hasattr(informacion_al_consumidor, 'fecha_inicio_anio_movil'):
+            if hasattr(informacion_al_consumidor, 'fecha_inicio_anio_movil') and bool(informacion_al_consumidor.fecha_inicio_anio_movil):
                 fecha_desde = informacion_al_consumidor.fecha_inicio_anio_movil
             else:
                 data_inici = datetime.strptime(fecha_hasta, '%Y-%m-%d')
