@@ -8,6 +8,7 @@ XSD_DATA.update({
     '41': {
         'A1': 'A141.xsd',
         'A2': 'A241.xsd',
+        'A25': 'A2541.xsd',
         'A3': 'A341.xsd',
         'A4': 'A441.xsd',
         'A3S': 'A3S41.xsd',
@@ -27,12 +28,14 @@ XSD_DATA.update({
     '05': {
         'A1': 'A105.xsd',
         'A2': 'A205.xsd',
+        'A25': 'A2505.xsd',
         'A3': 'A305.xsd',
         'A4': 'A405.xsd',
     },
     '44': {
         'A1': 'A144.xsd',
         'A2': 'A244.xsd',
+        'A25': 'A2544.xsd',
         'A3': 'A344.xsd',
         'A4': 'A444.xsd',
     },
@@ -44,6 +47,7 @@ XSD_DATA.update({
     '04': {
         'A1': 'A104.xsd',
         'A2': 'A204.xsd',
+        'A25': 'A2504.xsd',
         'A3': 'A304.xsd',
         'A4': 'A404.xsd',
     },
@@ -115,6 +119,7 @@ MAIN_MESSAGE_XSD.update({
     # 41
     'A141': 'a141',
     'A241': 'a241',
+    'A2541': 'a2541',
     'A341': 'a341',
     'A441': 'a441',
     'A3S41': 'a3s41',
@@ -130,11 +135,13 @@ MAIN_MESSAGE_XSD.update({
     # 05
     'A105': 'a105',
     'A205': 'a205',
+    'A2505': 'a2505',
     'A305': 'a305',
     'A405': 'a405',
     # 44
     'A144': 'a1',
     'A244': 'a2',
+    'A2544': 'a25',
     'A344': 'a3',
     'A444': 'a4',
     # 03
@@ -150,6 +157,7 @@ MAIN_MESSAGE_XSD.update({
     # 04
     'A104': 'a104',
     'A204': 'a204',
+    'A2504': 'a2504',
     'A304': 'a304',
     'A404': 'a404',
     # 46
